/**
 * @file ntm.c
 * @author Shinichiro Nakamura
 * @brief NTMの実装。
 */

/*
 * ===============================================================
 *  Natural Tiny Monitor (NT-Monitor)
 * ===============================================================
 * Copyright (c) 2011-2012 Shinichiro Nakamura
 * Inspired by M, Murakami
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 * ===============================================================
 */

#include "ntm.h"
#include "ntmuart.h"
#include "ntmcmd.h"
#include "ntmlibc.h"

/*
 * @brief 起動時に表示するバナー。
 * @details
 * このバナー表示内容はユーザが自由に編集してよい。
 * 自身の設計した装置に相応しい表示内容にする事ができる。
 */
static const char *DISPTEXT_BANNER =
    "\r\n"\
    "=============================================\r\n"\
    " Natural Tiny Monitor                        \r\n"\
    " Copyright (c) 2011-2012 Shinichiro Nakamura \r\n"\
    " Inspired by M, Murakami                     \r\n"\
    "=============================================\r\n";

/**
 * @brief Natural Tiny Monitorを実行する。
 * @details この関数は永遠に処理を返さない。
 * @param ntmshell シェルオブジェクト。
 */
void ntm_execute(ntmshell_t *ntmshell)
{

    /*
     * UARTの初期化を実行する。
     */
    ntmuart_init(NTMCONF_DEFAULT_BAUDRATE);

    /*
     * バナーを表示する。
     */
    ntmuart_write(DISPTEXT_BANNER, ntmlibc_strlen(DISPTEXT_BANNER));

    /*
     * シェルを実行する。
     */
    while (1) {
        ntmshell_execute(
                ntmshell,
                ntmuart_read,
                ntmuart_write,
                ntmcmd_execute,
                0);
    }
}

