/**
 * @file ntmio.c
 * @author Shinichiro Nakamura
 * @brief NTMが使用する入出力の実装。
 */

/*
 * ===============================================================
 *  Natural Tiny Monitor (NT-Monitor)
 * ===============================================================
 * Copyright (c) 2011-2012 Shinichiro Nakamura
 * Inspired by M, Murakami
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 * ===============================================================
 */

#include "ntmio.h"

void ntmio_read_byte(const uint32_t addr, uint8_t *data)
{
    *data = *((volatile uint8_t *)addr);
}

void ntmio_read_word(const uint32_t addr, uint16_t *data)
{
    *data = *((volatile uint16_t *)addr);
}

void ntmio_read_long(const uint32_t addr, uint32_t *data)
{
    *data = *((volatile uint32_t *)addr);
}

void ntmio_write_byte(const uint32_t addr, const uint8_t data)
{
    *((volatile uint8_t *)addr) = data;
}

void ntmio_write_word(const uint32_t addr, const uint16_t data)
{
    *((volatile uint16_t *)addr) = data;
}

void ntmio_write_long(const uint32_t addr, const uint32_t data)
{
    *((volatile uint32_t *)addr) = data;
}

